subst

package
v1.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 24, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IShift added in v1.6.0

func IShift(d, cutoff int, t ast.Term) ast.Term

IShift shifts all free interval variables >= cutoff by d positions. This operates in the interval variable namespace, separate from term variables.

func IShiftFace added in v1.6.0

func IShiftFace(d, cutoff int, f ast.Face) ast.Face

IShiftFace shifts interval variables in a face formula.

func ISubst added in v1.6.0

func ISubst(j int, s ast.Term, t ast.Term) ast.Term

ISubst substitutes interval term s for interval variable j in t. This operates in the interval variable namespace.

func ISubstFace added in v1.6.0

func ISubstFace(j int, s ast.Term, f ast.Face) ast.Face

ISubstFace substitutes an interval term for an interval variable in a face formula.

func Shift

func Shift(d, cutoff int, t ast.Term) ast.Term

Shift shifts all free de Bruijn variables >= cutoff by d positions. Follows TAPL 6.2.1.

func ShiftFace added in v1.6.0

func ShiftFace(d, cutoff int, f ast.Face) ast.Face

ShiftFace shifts term variables in a face formula (faces have no term vars).

func Subst

func Subst(j int, s ast.Term, t ast.Term) ast.Term

Subst substitutes s for variable j in t, adjusting indices. Follows TAPL 6.2.2.

func SubstFace added in v1.6.0

func SubstFace(j int, s ast.Term, f ast.Face) ast.Face

SubstFace substitutes a term for a term variable in a face formula.

Types

This section is empty.

Jump to