Documentation
¶
Index ¶
- func IShift(d, cutoff int, t ast.Term) ast.Term
- func IShiftFace(d, cutoff int, f ast.Face) ast.Face
- func ISubst(j int, s ast.Term, t ast.Term) ast.Term
- func ISubstFace(j int, s ast.Term, f ast.Face) ast.Face
- func Shift(d, cutoff int, t ast.Term) ast.Term
- func ShiftFace(d, cutoff int, f ast.Face) ast.Face
- func Subst(j int, s ast.Term, t ast.Term) ast.Term
- func SubstFace(j int, s ast.Term, f ast.Face) ast.Face
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IShift ¶ added in v1.6.0
IShift shifts all free interval variables >= cutoff by d positions. This operates in the interval variable namespace, separate from term variables.
func IShiftFace ¶ added in v1.6.0
IShiftFace shifts interval variables in a face formula.
func ISubst ¶ added in v1.6.0
ISubst substitutes interval term s for interval variable j in t. This operates in the interval variable namespace.
func ISubstFace ¶ added in v1.6.0
ISubstFace substitutes an interval term for an interval variable in a face formula.
func Shift ¶
Shift shifts all free de Bruijn variables >= cutoff by d positions. Follows TAPL 6.2.1.
func ShiftFace ¶ added in v1.6.0
ShiftFace shifts term variables in a face formula (faces have no term vars).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.